@@ -19,12 +19,13 @@ type schemaCmd struct {
 func newSchemaCmd() *schemaCmd {
 	root := &schemaCmd{}
 	cmd := &cobra.Command{
-		Use:           "jsonschema",
-		Aliases:       []string{"schema"},
-		Short:         "outputs goreleaser's JSON schema",
-		SilenceUsage:  true,
-		SilenceErrors: true,
-		Args:          cobra.NoArgs,
+		Use:               "jsonschema",
+		Aliases:           []string{"schema"},
+		Short:             "outputs goreleaser's JSON schema",
+		SilenceUsage:      true,
+		SilenceErrors:     true,
+		Args:              cobra.NoArgs,
+		ValidArgsFunction: cobra.NoFileCompletions,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			schema := jsonschema.Reflect(&config.Project{})
 			schema.Definitions["FileInfo"] = jsonschema.Reflect(&config.FileInfo{})
@@ -47,7 +48,8 @@ func newSchemaCmd() *schemaCmd {
 		},
 	}
 
-	cmd.Flags().StringVarP(&root.output, "output", "o", "-", "where to save the json schema")
+	cmd.Flags().StringVarP(&root.output, "output", "o", "-", "Where to save the JSONSchema file")
+	_ = cmd.MarkFlagFilename("output", "json")
 
 	root.cmd = cmd
 	return root
