@@ -349,6 +349,7 @@ func (c *githubClient) CreateRelease(ctx *context.Context, body string) (string,
 		Body:       github.String(body),
 		Draft:      github.Bool(ctx.Config.Release.Draft),
 		Prerelease: github.Bool(ctx.PreRelease),
+		MakeLatest: github.String("true"),
 	}
 
 	if ctx.Config.Release.DiscussionCategoryName != "" {
@@ -365,6 +366,10 @@ func (c *githubClient) CreateRelease(ctx *context.Context, body string) (string,
 		}
 	}
 
+	if latest := strings.TrimSpace(ctx.Config.Release.MakeLatest); latest == "false" {
+		data.MakeLatest = github.String(latest)
+	}
+
 	release, err := c.createOrUpdateRelease(ctx, data, body)
 	if err != nil {
 		return "", fmt.Errorf("could not release: %w", err)
