@@ -218,18 +218,12 @@ func doPush(ctx *context.Context, art *artifact.Artifact) error {
 
 func buildNuspec(ctx *context.Context, choco config.Chocolatey) ([]byte, error) {
 	tpl := tmpl.New(ctx)
-	summary, err := tpl.Apply(choco.Summary)
-	if err != nil {
-		return nil, err
-	}
 
-	description, err := tpl.Apply(choco.Description)
-	if err != nil {
-		return nil, err
-	}
-
-	releaseNotes, err := tpl.Apply(choco.ReleaseNotes)
-	if err != nil {
+	if err := tpl.ApplyAll(
+		&choco.Summary,
+		&choco.Description,
+		&choco.ReleaseNotes,
+	); err != nil {
 		return nil, err
 	}
 
@@ -251,9 +245,9 @@ func buildNuspec(ctx *context.Context, choco config.Chocolatey) ([]byte, error)
 			DocsURL:                  choco.DocsURL,
 			BugTrackerURL:            choco.BugTrackerURL,
 			Tags:                     choco.Tags,
-			Summary:                  summary,
-			Description:              description,
-			ReleaseNotes:             releaseNotes,
+			Summary:                  choco.Summary,
+			Description:              choco.Description,
+			ReleaseNotes:             choco.ReleaseNotes,
 		},
 		Files: Files{File: []File{
 			{Source: "tools\\**", Target: "tools"},
