@@ -3,7 +3,6 @@ package custompublishers
 
 import (
 	"github.com/goreleaser/goreleaser/internal/exec"
-	"github.com/goreleaser/goreleaser/internal/pipe"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
 
@@ -11,15 +10,13 @@ import (
 type Pipe struct{}
 
 // String returns the description of the pipe.
-func (Pipe) String() string {
-	return "custom publisher"
+func (Pipe) String() string { return "custom publisher" }
+
+func (Pipe) Skip(ctx *context.Context) bool {
+	return len(ctx.Config.Publishers) == 0 || ctx.SkipPublish
 }
 
 // Publish artifacts.
 func (Pipe) Publish(ctx *context.Context) error {
-	if len(ctx.Config.Publishers) == 0 {
-		return pipe.ErrSkipDisabledPipe
-	}
-
 	return exec.Execute(ctx, ctx.Config.Publishers)
 }
