@@ -106,6 +106,7 @@ func TestRunPipe(t *testing.T) {
 		Env: []string{
 			"PRO=pro",
 			"DESC=templates",
+			"EXT=.sh",
 		},
 		NFPMs: []config.NFPM{
 			{
@@ -132,6 +133,12 @@ func TestRunPipe(t *testing.T) {
 					Provides:         []string{"ash"},
 					Release:          "10",
 					Epoch:            "20",
+					Scripts: config.NFPMScripts{
+						PreInstall:  "./testdata/pre_install{{.Env.EXT}}",
+						PostInstall: "./testdata/post_install{{.Env.EXT}}",
+						PreRemove:   "./testdata/pre_remove{{.Env.EXT}}",
+						PostRemove:  "./testdata/post_remove{{.Env.EXT}}",
+					},
 					Contents: []*files.Content{
 						{
 							Destination: "/var/log/foobar",
@@ -1255,13 +1262,12 @@ func TestMeta(t *testing.T) {
 }
 
 func TestSkipSign(t *testing.T) {
-	folder, err := os.MkdirTemp("", "archivetest")
-	require.NoError(t, err)
+	folder := t.TempDir()
 	dist := filepath.Join(folder, "dist")
 	require.NoError(t, os.Mkdir(dist, 0o755))
 	require.NoError(t, os.Mkdir(filepath.Join(dist, "mybin"), 0o755))
 	binPath := filepath.Join(dist, "mybin", "mybin")
-	_, err = os.Create(binPath)
+	_, err := os.Create(binPath)
 	require.NoError(t, err)
 	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "mybin",
