@@ -602,15 +602,24 @@ func TestRunPipe(t *testing.T) {
 			goarch := "amd64"
 			createFakeArtifact("partial", goos, goarch, "v1", "", nil)
 			createFakeArtifact("foo", goos, goarch, "v1", "", nil)
-			createFakeArtifact("wrapped-in-dir", goos, goarch, "v1", "", map[string]any{artifact.ExtraWrappedIn: "foo"})
+			createFakeArtifact("wrapped-in-dir", goos, goarch, "v1", "", map[string]any{
+				artifact.ExtraWrappedIn: "foo",
+				artifact.ExtraBinaries:  []string{"bin/foo.exe"},
+			})
 
 			goarch = "386"
 			createFakeArtifact("foo", goos, goarch, "", "", nil)
-			createFakeArtifact("wrapped-in-dir", goos, goarch, "", "", map[string]any{artifact.ExtraWrappedIn: "foo"})
+			createFakeArtifact("wrapped-in-dir", goos, goarch, "", "", map[string]any{
+				artifact.ExtraWrappedIn: "foo",
+				artifact.ExtraBinaries:  []string{"bin/foo.exe"},
+			})
 
 			goarch = "arm64"
 			createFakeArtifact("foo", goos, goarch, "", "", nil)
-			createFakeArtifact("wrapped-in-dir", goos, goarch, "", "", map[string]any{artifact.ExtraWrappedIn: "foo"})
+			createFakeArtifact("wrapped-in-dir", goos, goarch, "", "", map[string]any{
+				artifact.ExtraWrappedIn: "foo",
+				artifact.ExtraBinaries:  []string{"bin/foo.exe"},
+			})
 
 			client := client.NewMock()
 			pipe := Pipe{}
@@ -647,7 +656,21 @@ func TestRunPipe(t *testing.T) {
 			require.NoError(t, pipe.publishAll(ctx, client))
 			require.True(t, client.CreatedFile)
 
-			require.Regexp(t, "New version: \\w+\\.[\\w-]+ 1.2.1", client.Message)
+			require.Len(t, client.Messages, 3)
+			expected := map[string]bool{
+				"locale":    false,
+				"version":   false,
+				"installer": false,
+			}
+			for _, msg := range client.Messages {
+				require.Regexp(t, "New version: \\w+\\.[\\w-]+ 1.2.1", msg)
+				for k, v := range expected {
+					if strings.Contains(msg, ": add "+k) {
+						require.False(t, v, "multiple commits for "+k)
+						expected[k] = true
+					}
+				}
+			}
 
 			require.NotEmpty(t, client.Path)
 			if tt.expectPath != "" {
